==> r-cran-proc_1.18.0.orig.tar.gz: pROC/tests/testthat/helper-roc.utils-expected.R <==
expected_roc.utils.calc.coords <-
structure(c(-1, -2, -3, -4, 1, 0.5, 0.1, 0, 0, 0.5, 0.9, 1, 0.36283185840708, 
0.5, 0.609734513274336, 0.63716814159292, 0, 36, 64.8, 72, 41, 
20.5, 4.1, 0, 0, 20.5, 36.9, 41, 72, 36, 7.2, 0, NaN, 0.63716814159292, 
0.63716814159292, 0.63716814159292, 0.36283185840708, 0.36283185840708, 
0.36283185840708, NaN, 1, 0.5, 0.1, 0, 0, 0.5, 0.9, 1, 1, 0.5, 
0.1, 0, 0, 0.5, 0.9, 1, 0.63716814159292, 0.63716814159292, 0.63716814159292, 
NaN, 1, 0.5, 0.1, 0, 0, 0.5, 0.9, 1, 0.63716814159292, 0.5, 0.390265486725664, 
0.36283185840708, NaN, 0.36283185840708, 0.36283185840708, 0.36283185840708, 
0.63716814159292, 0.63716814159292, 0.63716814159292, NaN, 0.36283185840708, 
0.36283185840708, 0.36283185840708, NaN, 1, 0.5, 0.1, 0, 1, 0.50462962962963, 
0.108333333333333, 0.00925925925925926, 0.00925925925925926, 
0.252314814814815, 0.810092592592593, 1), .Dim = c(4L, 24L), .Dimnames = list(
NULL, c("threshold", "sensitivity", "specificity", "accuracy", 
"tn", "tp", "fn", "fp", "npv", "ppv", "tpr", "tnr", "fpr", 
"fnr", "fdr", "1-specificity", "1-sensitivity", "1-accuracy", 
"1-npv", "1-ppv", "precision", "recall", "youden", "closest.topleft"
)))

expected_roc.utils.calc.coords.percent <-
structure(c(-1, -2, -3, -4, 100, 50, 10, 0, 0, 50, 90, 100, 36.283185840708, 
50, 60.9734513274336, 63.716814159292, 0, 36, 64.8, 72, 41, 20.5, 
4.1, 0, 0, 20.5, 36.9, 41, 72, 36, 7.2, 0, NaN, 63.716814159292, 
63.716814159292, 63.716814159292, 36.283185840708, 36.283185840708, 
36.283185840708, NaN, 100, 50, 10, 0, 0, 50, 90, 100, 100, 50, 
10, 0, 0, 50, 90, 100, 63.716814159292, 63.716814159292, 63.716814159292, 
NaN, 100, 50, 10, 0, 0, 50, 90, 100, 63.716814159292, 50, 39.0265486725664, 
36.283185840708, NaN, 36.283185840708, 36.283185840708, 36.283185840708, 
63.716814159292, 63.716814159292, 63.716814159292, NaN, 36.283185840708, 
36.283185840708, 36.283185840708, NaN, 100, 50, 10, 0, 100, 50.462962962963, 
10.8333333333333, 0.925925925925926, 0.925925925925926, 25.2314814814815, 
81.0092592592593, 100), .Dim = c(4L, 24L), .Dimnames = list(NULL, 
c("threshold", "sensitivity", "specificity", "accuracy", 
"tn", "tp", "fn", "fp", "npv", "ppv", "tpr", "tnr", "fpr", 
"fnr", "fdr", "1-specificity", "1-sensitivity", "1-accuracy", 
"1-npv", "1-ppv", "precision", "recall", "youden", "closest.topleft"
)))

==> r-cran-proc_1.18.5.orig.tar.gz: pROC/tests/testthat/helper-roc.utils-expected.R <==
expected_roc_utils_calc_coords <-
structure(c(-1, -2, -3, -4, 1, 0.5, 0.1, 0, 0, 0.5, 0.9, 1, 0.36283185840708, 
0.5, 0.609734513274336, 0.63716814159292, 0, 36, 64.8, 72, 41, 
20.5, 4.1, 0, 0, 20.5, 36.9, 41, 72, 36, 7.2, 0, NaN, 0.63716814159292, 
0.63716814159292, 0.63716814159292, 0.36283185840708, 0.36283185840708, 
0.36283185840708, NaN, 1, 0.5, 0.1, 0, 0, 0.5, 0.9, 1, 1, 0.5, 
0.1, 0, 0, 0.5, 0.9, 1, 0.63716814159292, 0.63716814159292, 0.63716814159292, 
NaN, 1, 0.5, 0.1, 0, 0, 0.5, 0.9, 1, 0.63716814159292, 0.5, 0.390265486725664, 
0.36283185840708, NaN, 0.36283185840708, 0.36283185840708, 0.36283185840708, 
0.63716814159292, 0.63716814159292, 0.63716814159292, NaN, 0.36283185840708, 
0.36283185840708, 0.36283185840708, NaN, 1, 0.5, 0.1, 0, 1, 0.50462962962963, 
0.108333333333333, 0.00925925925925926, 0.00925925925925926, 
0.252314814814815, 0.810092592592593, 1), .Dim = c(4L, 24L), .Dimnames = list(
NULL, c("threshold", "sensitivity", "specificity", "accuracy", 
"tn", "tp", "fn", "fp", "npv", "ppv", "tpr", "tnr", "fpr", 
"fnr", "fdr", "1-specificity", "1-sensitivity", "1-accuracy", 
"1-npv", "1-ppv", "precision", "recall", "youden", "closest.topleft"
)))

expected_roc_utils_calc_coords.percent <-
structure(c(-1, -2, -3, -4, 100, 50, 10, 0, 0, 50, 90, 100, 36.283185840708, 
50, 60.9734513274336, 63.716814159292, 0, 36, 64.8, 72, 41, 20.5, 
4.1, 0, 0, 20.5, 36.9, 41, 72, 36, 7.2, 0, NaN, 63.716814159292, 
63.716814159292, 63.716814159292, 36.283185840708, 36.283185840708, 
36.283185840708, NaN, 100, 50, 10, 0, 0, 50, 90, 100, 100, 50, 
10, 0, 0, 50, 90, 100, 63.716814159292, 63.716814159292, 63.716814159292, 
NaN, 100, 50, 10, 0, 0, 50, 90, 100, 63.716814159292, 50, 39.0265486725664, 
36.283185840708, NaN, 36.283185840708, 36.283185840708, 36.283185840708, 
63.716814159292, 63.716814159292, 63.716814159292, NaN, 36.283185840708, 
36.283185840708, 36.283185840708, NaN, 100, 50, 10, 0, 100, 50.462962962963, 
10.8333333333333, 0.925925925925926, 0.925925925925926, 25.2314814814815, 
81.0092592592593, 100), .Dim = c(4L, 24L), .Dimnames = list(NULL, 
c("threshold", "sensitivity", "specificity", "accuracy", 
"tn", "tp", "fn", "fp", "npv", "ppv", "tpr", "tnr", "fpr", 
"fnr", "fdr", "1-specificity", "1-sensitivity", "1-accuracy", 
"1-npv", "1-ppv", "precision", "recall", "youden", "closest.topleft"
)))
